# LHCToDD

[![Documentation Status][rtd-badge]][rtd-link]
[![PyPI version][pypi-version]][pypi-link]
[![PyPI platforms][pypi-platforms]][pypi-link]

[pypi-link]:                https://pypi.org/project/lhctodd/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/lhctodd
[pypi-version]:             https://badge.fury.io/py/lhctodd.svg
[rtd-badge]:                https://readthedocs.org/projects/lhctodd/badge/?version=latest
[rtd-link]:                 https://lhctodd.readthedocs.io/en/latest/?badge=latest
